# skan: skeleton analysis in Python
Python module to analyse skeleton (thin object) images

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/jni/skan/main?filepath=doc%2Fgetting_started.ipynb)
[![Coverage Status](https://coveralls.io/repos/github/jni/skan/badge.svg?branch=main)](https://coveralls.io/github/jni/skan?branch=master)

See the documentation at [https://skeleton-analysis.org](https://skeleton-analysis.org).
